import { Component, OnInit, Input } from '@angular/core';
import { NgbActiveModal } from '@ng-bootstrap/ng-bootstrap';
import {
  BackendService,
  ScrumTask,
  Priority,
  ScrumStatus,
  ScrumCategory,
  ScrumUser,
  ScrumProject,
  ScrumUserstory,
} from '../services/backend.service';
import { Observable } from 'rxjs';
import { HttpResponse } from '@angular/common/http';

@Component({
  selector: 'app-task-form',
  templateUrl: './task-form.component.html',
  styleUrls: ['./task-form.component.css'],
})
export class TaskFormComponent implements OnInit {
  @Input() public task: ScrumTask;
  public editing: Boolean;
  public userstoryId: string;

  constructor(
    private backendService: BackendService,
    private activeModalService: NgbActiveModal
  ) {}

  ngOnInit(): void {
    if (this.task === null || this.task === undefined) {
      this.task = { title: '' };
      this.editing = false;
    } else {
      this.editing = true;
    }
    document.getElementById('titleField').focus();
    this.getRelatedStory();
  }

  onSubmit() {
    if (this.editing) {
      this.backendService.putTask(this.task).subscribe((response) => {
        if (response.status > 399) {
          alert('Fehler');
        }
      });
    } else {
      this.backendService.postTask(this.task).subscribe((response) => {
        if (response.status > 399) {
          alert('Fehler');
        }
      });
    }
    this.activeModalService.close(this.task);
  }

  onClose() {
    this.activeModalService.dismiss(this.task);
  }

  getRelatedStory() {
    this.backendService.getUserstory(2).subscribe((response) => {
      if (response.status > 399) {
        alert('Fehler');
      } else {
        this.userstoryId = response.body.title;
      }
    });
  }
}
